@@ -40,7 +40,7 @@ use self::{
   pods::{KubeContainer, KubePod},
   replicasets::KubeReplicaSet,
   replication_controllers::KubeReplicationController,
-  roles::{KubeClusterRoleBinding, KubeClusterRoles, KubeRoleBindings, KubeRoles},
+  roles::{KubeClusterRole, KubeClusterRoleBinding, KubeRole, KubeRoleBinding},
   secrets::KubeSecret,
   statefulsets::KubeStatefulSet,
   storageclass::KubeStorageClass,
@@ -133,9 +133,9 @@ pub struct Data {
   pub secrets: StatefulTable<KubeSecret>,
   pub rpl_ctrls: StatefulTable<KubeReplicationController>,
   pub storage_classes: StatefulTable<KubeStorageClass>,
-  pub roles: StatefulTable<KubeRoles>,
-  pub role_bindings: StatefulTable<KubeRoleBindings>,
-  pub cluster_roles: StatefulTable<KubeClusterRoles>,
+  pub roles: StatefulTable<KubeRole>,
+  pub role_bindings: StatefulTable<KubeRoleBinding>,
+  pub cluster_roles: StatefulTable<KubeClusterRole>,
   pub cluster_role_binding: StatefulTable<KubeClusterRoleBinding>,
 }
 
@@ -408,7 +408,6 @@ impl App {
     if let Some(io_tx) = &self.io_tx {
       if let Err(e) = io_tx.send(action).await {
         self.is_loading = false;
-        println!("Error from network dispatch {}", e);
         self.handle_error(anyhow!(e));
       };
     }
@@ -421,7 +420,6 @@ impl App {
     if let Some(io_stream_tx) = &self.io_stream_tx {
       if let Err(e) = io_stream_tx.send(action).await {
         self.is_loading = false;
-        println!("Error from stream dispatch {}", e);
         self.handle_error(anyhow!(e));
       };
     }
@@ -434,7 +432,6 @@ impl App {
     if let Some(io_cmd_tx) = &self.io_cmd_tx {
       if let Err(e) = io_cmd_tx.send(action).await {
         self.is_loading = false;
-        println!("Error from cmd dispatch {}", e);
         self.handle_error(anyhow!(e));
       };
     }
@@ -528,6 +525,7 @@ impl App {
     self.dispatch(IoEvent::GetNamespaces).await;
     self.dispatch(IoEvent::GetPods).await;
     self.dispatch(IoEvent::GetServices).await;
+    self.dispatch(IoEvent::GetNodes).await;
     self.dispatch(IoEvent::GetConfigMaps).await;
     self.dispatch(IoEvent::GetStatefulSets).await;
     self.dispatch(IoEvent::GetReplicaSets).await;
@@ -669,15 +667,12 @@ mod test_utils {
     <K as Resource>::DynamicType: Default,
     K: Clone + DeserializeOwned + fmt::Debug,
     K: Resource,
-    T: KubeResource<K>,
+    T: KubeResource<K> + From<K>,
   {
     let res_list = load_resource_from_file(filename);
     let original_res_list = res_list.items.clone();
 
-    let resources: Vec<T> = res_list
-      .iter()
-      .map(|it| T::from_api(it))
-      .collect::<Vec<_>>();
+    let resources: Vec<T> = res_list.into_iter().map(K::into).collect::<Vec<_>>();
 
     (resources, original_res_list)
   }
@@ -739,6 +734,7 @@ mod tests {
     assert_eq!(sync_io_rx.recv().await.unwrap(), IoEvent::GetNamespaces);
     assert_eq!(sync_io_rx.recv().await.unwrap(), IoEvent::GetPods);
     assert_eq!(sync_io_rx.recv().await.unwrap(), IoEvent::GetServices);
+    assert_eq!(sync_io_rx.recv().await.unwrap(), IoEvent::GetNodes);
     assert_eq!(sync_io_rx.recv().await.unwrap(), IoEvent::GetConfigMaps);
     assert_eq!(sync_io_rx.recv().await.unwrap(), IoEvent::GetStatefulSets);
     assert_eq!(sync_io_rx.recv().await.unwrap(), IoEvent::GetReplicaSets);
@@ -794,6 +790,7 @@ mod tests {
     assert_eq!(sync_io_rx.recv().await.unwrap(), IoEvent::GetNamespaces);
     assert_eq!(sync_io_rx.recv().await.unwrap(), IoEvent::GetPods);
     assert_eq!(sync_io_rx.recv().await.unwrap(), IoEvent::GetServices);
+    assert_eq!(sync_io_rx.recv().await.unwrap(), IoEvent::GetNodes);
     assert_eq!(sync_io_rx.recv().await.unwrap(), IoEvent::GetConfigMaps);
     assert_eq!(sync_io_rx.recv().await.unwrap(), IoEvent::GetStatefulSets);
     assert_eq!(sync_io_rx.recv().await.unwrap(), IoEvent::GetReplicaSets);
